<?php
/**
 * Twenty Twelve functions and definitions.
 *
 * Sets up the theme and provides some helper functions, which are used
 * in the theme as custom template tags. Others are attached to action and
 * filter hooks in WordPress to change core functionality.
 *
 * When using a child theme (see http://codex.wordpress.org/Theme_Development and
 * http://codex.wordpress.org/Child_Themes), you can override certain functions
 * (those wrapped in a function_exists() call) by defining them first in your child theme's
 * functions.php file. The child theme's functions.php file is included before the parent
 * theme's file, so the child theme functions would be used.
 *
 * Functions that are not pluggable (not wrapped in function_exists()) are instead attached
 * to a filter or action hook.
 *
 * For more information on hooks, actions, and filters, see http://codex.wordpress.org/Plugin_API.
 *
 * @package WordPress
 * @subpackage Twenty_Twelve
 * @since Twenty Twelve 1.0
 */

/**
 * Table of Contents:
 *
 *  1.0 - Parent theme's functions you can override
 *    1.1 - Tip00 - Style navigation arrows for post listing (next/previous page navigation)
 *  2.0 - Custom 2012-XTended functions
 *    2.1 - Tip01 - Properly include additional CSS and JavaScript files via functions.php - http://mtomas.com/27/
 *    2.2 - Tip02 - Add new image size for custom post/page headers and select default header image
 *    2.3 - Tip03 - Mark main navigation menu items, containing children with special css class .dropdown
 *    2.4 - Tip04 - Print HTML bellow post title with meta information for the current post date/time and author
 *    2.5 - Tip05 - Remove junk from head
 *    2.6 - Tip06 - Remove WordPress version info from head and feeds
 *    2.7 - Tip07 - No more jumping for read more link
 *    2.8 - Tip08 - Remove curly quotes in WordPress
 *    2.9 - Tip09 - Properly resize videos, inserted with oembed
 *    2.10 - Tip12 - Completely disable the Post Formats UI in the post editor screen
 *    2.11 - Tip13 - Add Twenty Thirteen search form to WordPress nav menu
 *    2.12 - Default core markup for forms to output valid HTML5
 *  3.0 - Tip10 - Custom functions and styles for the Schema.org microdata format support implementation
 *    3.1 - Tip11 - Register three footer widget areas
 *    3.2 - Template for comments and pingbacks
 *    3.3 - Print HTML with meta information for current post: categories, tags, permalink, author, and date
 *    3.4 - Add Schema.org author markup to comment author links
 *    3.5 - Allow Schema.org attributes to be added to HTML tags in the editor (but not for comments)
 * ----------------------------------------------------------------------------
 */

// 1.0 - Parent theme's functions you can override

// 1.1 - Tip00 - Style navigation arrows for post listing (next/previous page navigation)
if ( ! function_exists( 'twentytwelve_content_nav' ) ) :

function twentytwelve_content_nav( $html_id ) {
	global $wp_query;
	
	$html_id = esc_attr( $html_id );

	if ( $wp_query->max_num_pages > 1 ) : ?>
		<nav id="<?php echo $html_id; ?>" class="navigation" role="navigation">
			<h3 class="assistive-text"><?php _e( 'Post navigation', 'twentytwelve' ); ?></h3>
			<div class="nav-previous"><?php next_posts_link( __( '<span class="meta-nav">&laquo;</span> OLDER ARTICLES', 'twentytwelve' ) ); ?></div>
			<div class="nav-next"><?php previous_posts_link( __( 'NEWER ARTICLES <span class="meta-nav">&raquo;</span>', 'twentytwelve' ) ); ?></div>
		</nav><!-- #<?php echo $html_id; ?> .navigation -->
	<?php endif;
}
endif;


// 2.0 - Custom 2012-XTended functions

// 2.1 - Tip01 - Properly include additional CSS and JavaScript files via functions.php
function my_scripts_and_styles() {

	// First adding CSS file of the Parent theme
	wp_register_style( 'twentytwelve-style', 
    get_template_directory_uri() . '/style.css', 
    array(), 
    '3.5.1', 
    'all' );
	
	// Adding CSS file of the Elusive-icon font
	wp_register_style( 'elusive-iconfont-style', 
    get_stylesheet_directory_uri() . '/css/elusive-webfont.css', 
    array(), 
    '1.0', 
    'all' );
	
	// Adding CSS file of the Child theme
	// This style sheet stands last so it would override parent theme and other stylesheets
	wp_register_style( '2012-XTended-style', 
    get_stylesheet_uri(), 
    array(), 
    '1.0', 
    'all' );
	
	// enqueing:
	wp_enqueue_style( 'twentytwelve-style' );
	wp_enqueue_style( 'elusive-iconfont-style' );
	wp_enqueue_style( '2012-XTended-style' );
	// Below is an example how to enqueue the script
	// wp_enqueue_script( 'your-script-name', get_stylesheet_directory_uri() . '/js/your-script-file-name.js' );
}
add_action( 'wp_enqueue_scripts', 'my_scripts_and_styles' );


// 2.2 - Tip02 - Add new image size for custom post/page headers and select default header image (also see Tip39 in style.css)
if ( function_exists( 'add_theme_support' ) ) { 
add_image_size( 'custom-header-image', 960, 9999 ); // 960 pixels wide (and unlimited height)
}
// Define default header image which TwentyTwelve doesn't have
// Thanks to paulwpxp - http://wordpress.org/support/topic/setting-default-header-image-in-child-theme
function mytheme_custom_header_setup() {
	// $args in add_theme_support() in child theme will auto override what defined in parent's
	// see http://core.trac.wordpress.org/browser/tags/3.5/wp-includes/theme.php#L1292
	$args = array(
		'default-image' => get_stylesheet_directory_uri() . '/images/headers/2012-XTended-header.jpg',
	);
	add_theme_support( 'custom-header', $args );
}
// add it the same way Twenty Twelve does
add_action( 'after_setup_theme', 'mytheme_custom_header_setup' );


// 2.3 - Tip03 - Mark main navigation menu items, containing children with special css class .dropdown
// Main navigation menu items with drop-down children will be marked by a distinct icon (caret down) via style.css
// http://stackoverflow.com/questions/8448978/wordpress-how-do-i-know-if-a-menu-item-has-children
function menu_set_dropdown( $sorted_menu_items, $args ) {
    $last_top = 0;
    foreach ( $sorted_menu_items as $key => $obj ) {
        // it is a top lv item?
        if ( 0 == $obj->menu_item_parent ) {
            // set the key of the parent
            $last_top = $key;
        } else {
            $sorted_menu_items[$last_top]->classes['dropdown'] = 'dropdown';
        }
    }
    return $sorted_menu_items;
}
add_filter( 'wp_nav_menu_objects', 'menu_set_dropdown', 10, 2 );


// 2.4 - Tip04 - Print HTML bellow post title with meta information for the current post date/time and author
function twentytwelve_entry_meta_top() {
	$date = sprintf( '<time class="entry-date updated" datetime="%3$s" itemprop="datePublished">%4$s</time>',
		esc_url( get_permalink() ),
		esc_attr( get_the_time() ),
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() )
	);

	$author = sprintf( '<span class="author vcard" itemprop="author" itemscope itemtype="http://schema.org/Person"><span itemprop="name"><a class="url fn n" href="%1$s" title="%2$s" rel="author" itemprop="url">%3$s</a></span></span>',
		esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
		esc_attr( sprintf( __( 'View all posts by %s', 'twentytwelve' ), get_the_author() ) ),
		get_the_author()
	);

	// Translators: 1 is the date and 2 is the author's name
		$utility_text = __( '%1$s<span class="by-author"> by %2$s</span> ', 'twentytwelve' );

	printf(
		$utility_text,
		$date,
		$author
	);
}


// 2.5 - Tip05 - Remove junk from head
remove_action('wp_head', 'rsd_link');
remove_action('wp_head', 'wp_generator');
remove_action('wp_head', 'index_rel_link');
remove_action('wp_head', 'wlwmanifest_link');


// 2.6 - Tip06 - Remove WordPress version info from head and feeds
function complete_version_removal() {
	return '';
}
add_filter('the_generator', 'complete_version_removal');


// 2.7 - Tip07 - No more jumping for read more link
// Clicking on "read more" or "continue reading" sends user to the top of the post, not to the place marked with "more"
function remove_more_jump_link($link) { 
$offset = strpos($link, '#more-');
if ($offset) {
$end = strpos($link, '"',$offset);
}
if ($end) {
$link = substr_replace($link, '', $offset, $end-$offset);
}
return $link;
}
add_filter('the_content_more_link', 'remove_more_jump_link');


// 2.8 - Tip08 - Remove curly quotes in WordPress
remove_filter('the_content', 'wptexturize');


// 2.9 - Tip09 - Properly resize videos, inserted with oembed
// By Marty Kokes: http://wordpress.org/support/topic/properly-resizing-videos-possible-code-addition
function css_oembed_filter($html, $url, $attr, $post_ID) {
    $return = '<div class="video-wrapper"><figure class="video-container">'.$html.'</figure></div>';
    return $return;
}


// 2.10 - Tip12 - Completely disable the Post Formats UI in the post editor screen
// Have a normal/business website and do not really use or need Post Formats? http://www.wptavern.com/post-format-history-and-wordpress-3-6
// Uncomment next line to completely disable the Post Formats UI in the post editor screen:
// add_filter( 'enable_post_format_ui', '__return_false' );


// 2.11 - Tip13 - Add Twenty Thirteen search form to WordPress nav menu, also see style.css
// http://diythemes.com/thesis/rtfm/add-search-form-wp-wordpress-nav-menus/
function add_search_to_wp_menu ( $items, $args ) {
	if( 'primary' === $args -> theme_location ) {
	$items .= '<li class="menu-item menu-item-search">';
	$items .= '<form role="search" method="get" class="searchform" action="' . get_bloginfo('home') . '/"><label><span class="screen-reader-text">Search for:</span></label>';
	$items .= '<input class="text_input" type="search" value="" name="s" id="s" placeholder="Search &hellip;" title="Search for:" /><input type="submit" class="searchsubmit" value="Search" /></form>';
	$items .= '</li>';
	}
	return $items;
}
add_filter('wp_nav_menu_items','add_search_to_wp_menu',10,2);


// 2.12 - Default core markup for forms to output valid HTML5
function mytheme_html5_forms_setup() {
	add_theme_support( 'html5', array( 'search-form', 'comment-form', 'comment-list' ) );
}
// add it the same way Twenty Twelve does
add_action( 'after_setup_theme', 'mytheme_html5_forms_setup' );


// 3.0 - Tip10 - Custom functions and styles for the Schema.org microdata format support implementation, also see style.css
// By Joshua Lyman: http://www.joshualyman.com/twenty-twelve-schema-org-child-theme/
// Github: http://github.com/jlyman/Twenty-Twelve-Schema.org-Child-Theme

// 3.1 - Registers three footer widget areas
function twentytwelve_extra_widgets_init() {
	register_sidebar( array(
		'name' => __( 'Footer Widget Area', 'twentytwelve' ),
		'id' => 'sidebar-4',
		'description' => __( 'Found at the bottom of every page (except 404s) as the footer. Left Side.', 'twentytwelve' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => '</aside>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );

	register_sidebar( array(
		'name' => __( 'Footer Area One', 'twentytwelve' ),
		'id' => 'sidebar-5',
		'description' => __( 'Found at the bottom of every page (except 404s) as the footer. Center.', 'twentytwelve' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );

	register_sidebar( array(
		'name' => __( 'Footer Area Two', 'twentytwelve' ),
		'id' => 'sidebar-6',
		'description' => __( 'Found at the bottom of every page (except 404s) as the footer. Right Side.', 'twentytwelve' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );
}
add_action( 'widgets_init', 'twentytwelve_extra_widgets_init' );


// 3.2 - Template for comments and pingbacks
if ( ! function_exists( 'twentytwelve_comment' ) ) :
/**
 * To override this walker in a child theme without modifying the comments template
 * simply create your own twentytwelve_comment(), and that function will be used instead
 *
 * Used as a callback by wp_list_comments() for displaying the comments.
 */
function twentytwelve_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	switch ( $comment->comment_type ) :
		case 'pingback' :
		case 'trackback' :
		// Display trackbacks differently than normal comments
	?>
	<li <?php comment_class(); ?> id="comment-<?php comment_ID(); ?>">
		<p><?php _e( 'Pingback:', 'twentytwelve' ); ?> <?php comment_author_link(); ?> <?php edit_comment_link( __( '(Edit)', 'twentytwelve' ), '<span class="edit-link">', '</span>' ); ?></p>
	<?php
			break;
		default :
		// Proceed with normal comments
		global $post;
	?>
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
		<article id="comment-<?php comment_ID(); ?>" class="comment" itemprop="comment" itemscope itemtype="http://schema.org/UserComments">
			<header class="comment-meta comment-author vcard" itemprop="creator" itemscope itemtype="http://schema.org/Person">
				<?php
					echo get_avatar( $comment, 44 );
					printf( '<cite><b class="fn">%1$s</b> %2$s</cite>',
						get_comment_author_link(),
						// If current post author is also comment author, make it known visually
						( $comment->user_id === $post->post_author ) ? '<span>' . __( 'Post author', 'twentytwelve' ) . '</span>' : ''
					);
					printf( '<a href="%1$s"><time datetime="%2$s" itemprop="commentTime">%3$s</time></a>',
						esc_url( get_comment_link( $comment->comment_ID ) ),
						get_comment_time( 'c' ),
						// translators: 1: date, 2: time
						sprintf( __( '%1$s at %2$s', 'twentytwelve' ), get_comment_date(), get_comment_time() )
					);
				?>
			</header><!-- .comment-meta -->

			<?php if ( '0' == $comment->comment_approved ) : ?>
				<p class="comment-awaiting-moderation"><?php _e( 'Your comment is awaiting moderation.', 'twentytwelve' ); ?></p>
			<?php endif; ?>

			<section class="comment-content comment" itemprop="commentText">
				<?php comment_text(); ?>
				<?php edit_comment_link( __( 'Edit', 'twentytwelve' ), '<p class="edit-link">', '</p>' ); ?>
			</section><!-- .comment-content -->

			<div class="reply">
				<?php comment_reply_link( array_merge( $args, array( 'reply_text' => __( 'Reply', 'twentytwelve' ), 'after' => ' <span>&darr;</span>', 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
			</div><!-- .reply -->
		</article><!-- #comment-## -->
	<?php
		break;
	endswitch; // end comment_type check
}
endif;


// 3.3 - Print HTML with meta information for current post: categories, tags, permalink, author, and date
if ( ! function_exists( 'twentytwelve_entry_meta' ) ) :

function twentytwelve_entry_meta() {
	// Translators: used between list items, there is a space after the comma
	$categories_list = get_the_category_list( __( '</span>, <span itemprop="articleSection">', 'twentytwelve' ) );

	// Translators: used between list items, there is a space after the comma
	$tag_list = get_the_tag_list( '', __( ', ', 'twentytwelve' ) );

	$date = sprintf( '<a href="%1$s" title="%2$s" rel="bookmark"><time class="entry-date updated" datetime="%3$s" itemprop="datePublished">%4$s</time></a>',
		esc_url( get_permalink() ),
		esc_attr( get_the_time() ),
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() )
	);

	$author = sprintf( '<span class="author vcard" itemprop="author" itemscope itemtype="http://schema.org/Person"><span itemprop="name"><a class="url fn n" href="%1$s" title="%2$s" rel="author" itemprop="url">%3$s</a></span></span>',
		esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
		esc_attr( sprintf( __( 'View all posts by %s', 'twentytwelve' ), get_the_author() ) ),
		get_the_author()
	);

	// Translators: 1 is category, 2 is tag, 3 is the date and 4 is the author's name
	if ( $tag_list ) {
		$utility_text = __( 'Posted in <span itemprop="articleSection">%1$s</span>.', 'twentytwelve' );
		/* $utility_text = __( 'Posted in <span itemprop="articleSection">%1$s</span> and tagged <span itemprop="keywords">%2$s</span> on %3$s<span class="by-author"> by %4$s</span>.', 'twentytwelve' ); */
	} elseif ( $categories_list ) {
		$utility_text = __( 'Posted in <span itemprop="articleSection">%1$s</span>.', 'twentytwelve' );
	} else {
		$utility_text = __( 'Posted on %3$s<span class="by-author"> by %4$s</span>.', 'twentytwelve' );
	}

	printf(
		$utility_text,
		$categories_list,
		$tag_list,
		$date,
		$author
	);
}
endif;


// 3.4 - Add Schema.org author markup to comment author links
if ( ! function_exists( 'twentytwelve_comment_author_hook' ) ) :

function twentytwelve_comment_author_hook( $author_code ) {
	if (substr($author_code, 0, 2) == '<a') {
		$author_code = substr($author_code, 0, -1) . ' itemprop="url">';
	}
	return '<p class="comment-author-name" itemprop="name">' . $author_code . '</p>'; // Can't use a span tag because of conflicting styles on .bypostauthor
}
add_filter('get_comment_author_link', 'twentytwelve_comment_author_hook');
endif;


// 3.5 - Allow Schema.org attributes to be added to HTML tags in the editor (but not for comments)
if ( ! function_exists( 'twentytwelve_allow_schema_markup' ) ) :

function twentytwelve_allow_schema_markup() {
	global $allowedposttags;
	foreach( $allowedposttags as $tag => $attr ) {
		$attr[ 'itemscope' ] = array();
		$attr[ 'itemtype' ] = array();
		$attr[ 'itemprop' ] = array();
		$allowedposttags[ $tag ] = $attr;
	}
	return $allowedposttags;
}

add_action( 'init', 'twentytwelve_allow_schema_markup' );
endif;